<?php
namespace Pinpoint\LogoManager\Controller\Adminhtml\Logo;

use Magento\Backend\App\Action;

/**
 * Class Delete
 * @package Pinpoint\LogoManager\Controller\Adminhtml\Logo
 */
class Delete extends \Magento\Backend\App\Action
{
    /**
     * @var \Pinpoint\LogoManager\Model\LogoRepository
     */
    protected $logo;

    /**
     * @var string
     */
    const ADMIN_RESOURCE = 'Pinpoint_LogoManager::logo_manager';

    /**
     * Delete constructor.
     * @param Action\Context $context
     * @param \Pinpoint\LogoManager\Model\LogoRepository $logo
     */
    public function __construct(
        Action\Context $context,
        \Pinpoint\LogoManager\Model\LogoRepository $logo
    ) {
        $this->logo = $logo;

        parent::__construct($context);
    }

    /**
     * @return bool
     */
    protected function _isAllowed()
    {
        return $this->_authorization->isAllowed('Pinpoint_LogoManager::logo_manager');
    }

    /**
     * @return $this
     */
    public function execute()
    {
        // check if we know what should be deleted
        $id = $this->getRequest()->getParam('id');
        /** @var \Magento\Backend\Model\View\Result\Redirect $resultRedirect */
        $resultRedirect = $this->resultRedirectFactory->create();
        if ($id) {
            try {
                $this->logo->deleteById($id);
                $this->messageManager->addSuccessMessage(__('You have deleted the logo.'));
                // go to grid
                return $resultRedirect->setPath('*/*/list');
            } catch (\Exception $e) {
                // display error message
                $this->messageManager->addErrorMessage($e->getMessage());
                // go back to edit form
                return $resultRedirect->setPath('*/*/edit', ['id' => $id]);
            }
        }
        // display error message
        $this->messageManager->addErrorMessage(__('We can not find the logo to delete.'));
        // go to grid
        return $resultRedirect->setPath('*/*/list');
        
    }    
    
}
